@@ -12,6 +12,7 @@ static ANSIBLE_TASKS: &str = include_str!("../data/ansible_tasks.txt");
 static RKHUNTER_CHECKS: &str = include_str!("../data/rkhunter_checks.txt");
 static RKHUNTER_ROOTKITS: &str = include_str!("../data/rkhunter_rootkits.txt");
 static RKHUNTER_TASKS: &str = include_str!("../data/rkhunter_tasks.txt");
+static JULIA_PACKAGES: &str = include_str!("../data/julia.csv");
 
 lazy_static::lazy_static! {
     pub static ref BOOTLOG_LIST: Vec<&'static str> = BOOTLOG.lines().collect();
@@ -28,6 +29,17 @@ lazy_static::lazy_static! {
     pub static ref RKHUNTER_CHECKS_LIST: Vec<&'static str> = RKHUNTER_CHECKS.lines().collect();
     pub static ref RKHUNTER_ROOTKITS_LIST: Vec<&'static str> = RKHUNTER_ROOTKITS.lines().collect();
     pub static ref RKHUNTER_TASKS_LIST: Vec<&'static str> = RKHUNTER_TASKS.lines().collect();
+    pub static ref JULIA_PACKAGES_LIST: Vec<crate::modules::julia::Package<'static>> = JULIA_PACKAGES
+        .lines()
+        .map(|line| {
+            let mut split = line.split(',');
+            let name = split.next().unwrap_or("Revise");
+            let id = split.next().unwrap_or("295af30f");
+            let versions = split.collect();
+            crate::modules::julia::Package { name, id, versions }
+        })
+        .collect();
+
 }
 
 pub static EXTENSIONS_LIST: &[&str] = &[
